@@ -67,6 +67,7 @@
 /*---------------------------------------------------------------------------*/
 
 #include "mrilib.h"
+#include "3ddata.h"
 
 static char * commandline = NULL ;         /* command line for history notes */
 
@@ -444,6 +445,12 @@ void add_file_name (THD_3dim_dataset * new_dset, char * filename,
 		    char * command_str);
 
 
+/*---------------------------------------------------------------------------*/
+/*
+   Routine to get a nice string to use as sub-brick label.
+*/
+char *label_from_filename(char *fname);
+
 /*---------------------------------------------------------------------------*/
 /*
    Routine to remove AFNI .HEAD and .BRIK dataset files.
