@@ -688,6 +688,22 @@ int main( int argc , char *argv[] )
       "similar fashion, using the error sum of squares between 2 different fits.\n"
       "(Of course, these are assuming you use the default '-lsqfit' method.)\n"
       "\n"
+      "--------------------------------\n"
+      "PPI (psycho-physiological interaction) Example:\n"
+      "--------------------------------\n"
+      "Suppose you are running a PPI analysis and want to deconvolve a GAM\n"
+      "signal from the seed time series, hoping (very optimistically) to\n"
+      "convert from the BOLD time series (typical FMRI signal) to a\n"
+      "neurological time series (an impulse signal, say).\n"
+      "\n"
+      "If the BOLD signal at the seed is seed_BOLD.1D and the GAM signal is\n"
+      "GAM.1D, then consider this example for the deconvolution, in order to\n"
+      "create the neuro signal, seed_neuro.1D:\n"
+      "\n"
+      "  3dTfitter -RHS seed_BOLD.1D                    \\\n"
+      "            -FALTUNG GAM.1D seed_neuro.1D 012 -2 \\\n"
+      "            -l2lasso -6\n"
+      "\n"
       "*************************************************************************\n"
       "** RWCox - Feb 2008, et seq.                                           **\n"
       "** Created for the glorious purposes of John A Butman, MD, PhD, Poobah **\n"
