@@ -181,7 +181,7 @@ while (anotherLag) {
 nLags <- as.integer(readline("Select order of VAR model (e.g., 1)? "))
 
 outFN <- readline("Output file name (no view+suffix needed, e.g., myOutput): ")
-outFN <- paste(outFN, "+orig", sep="")
+outFN <- paste(outFN, "+", outView, sep="")
 
 # generate intervention dummy variables for across-run/block breaks: nLags dummies per run
 if (nChunks > 1) {
@@ -310,15 +310,14 @@ for (ii in 1:nLags) {
    outLabel <- append(outLabel, sprintf("t for target-to-seed lag %i", ii))
 }
  
-write.AFNI(outFN, outData, outLabel, note=myNote, origin=myOrig, delta=myDelta, idcode="whatever")
+write.AFNI(outFN, outData, outLabel, note=myNote, origin=myOrig, delta=myDelta, idcode=newid.AFNI())
 
 statpar <- "3drefit"
    for (ii in 1:nLags) for (jj in 1:3) {
 	   statpar <- paste(statpar, " -substatpar ", 6*(ii-1)+2*jj-1, 
 	   " fitt ", summary(fm)$varresult[[1]]$df[2])
 	}
-if (outView=="tlrc") statpar <- paste(statpar, " -view tlrc -addFDR -newid -orient ", dataOrient, outFN)
-if (outView=="orig") statpar <- paste(statpar, "-addFDR -newid -orient ", dataOrient, outFN)
+statpar <- paste(statpar, "-addFDR -newid -orient ", dataOrient, outFN)
 system(statpar)
 
 
