@@ -52,6 +52,7 @@ typedef struct {
    DList *DisplayUpdates;
    SUMA_SegmentDO *SDO;
    SUMA_NIDO *nido;
+   SUMA_SurfaceObject *FrameSO; /*!< Matrix's holder surface object */
    SUMA_OVERLAYS *Overlay;
    SUMA_X_SurfCont *DOCont;/*!< Displayable object controller */
    SUMA_PICK_RESULT *PR;
@@ -62,15 +63,147 @@ typedef struct {
    SUMA_NGR_INDEX_HASH_DATUM *thd; /*! A hash table pointing to niml element
                                        containing tract to represent path
                                        between two points */
+   SUMA_Boolean ShowBundles; /*!< Show bundles instead of edge if possible */
+   SUMA_Boolean ShowUncon; /*!< Show graph points (nodes) even if not 
+                                  connected */
+   SUMA_Boolean IgnoreSelection; /*!< Ignore selection mode when displaying
+                                      Currently used to show all graph, even
+                                      when one node is selected */
+   float *Center_G3D; /* Geometric center of all points in 3D variant*/
+   float *Range_G3D;  /* Min Max of X, Y, and Z of all points in 3D variant*/
+   float *Center_GMATRIX; /* Geometric center of all points in MATRIX 
+                             variant*/
+   float *Range_GMATRIX;  /* Min Max of X, Y, and Z of all points in MATRIX 
+                             variant*/
 } SUMA_GRAPH_SAUX;
 
+/*! A Tract object's Auxiliary structure for SUMA's use */
+typedef struct {
+   DList *DisplayUpdates;
+   SUMA_X_SurfCont *DOCont;/*!< Displayable object controller */
+   SUMA_PICK_RESULT *PR;
+   SUMA_OVERLAYS **Overlays;
+   int N_Overlays;
+   SUMA_Boolean *isColored; /*!< is the datum receiving color? Not masked say 
+                                 by thresholds etc. */
+   int TractMask;
+   float MaskGray;
+   float *tract_lengths;
+   
+   float *Center; /* Geometric center of all points */
+   float *Range;  /* Min Max of X, Y, and Z of all points */
+} SUMA_TRACT_SAUX;
+
+/*! A Mask object's Auxiliary structure for SUMA's use */
+typedef struct {
+   DList *DisplayUpdates;
+   SUMA_X_SurfCont *DOCont;/*!< Displayable object controller */
+   SUMA_PICK_RESULT *PR;
+   SUMA_OVERLAYS **Overlays;
+   int N_Overlays;
+   SUMA_Boolean *isColored; /*!< is the datum receiving color? Not masked say 
+                                 by thresholds etc. */
+} SUMA_MASK_SAUX;
+
+
+/*! A Surface object's Auxiliary structure for SUMA's use */
+typedef struct {
+   #if 0 /* Not in use yet*/
+   DList *DisplayUpdates;
+   SUMA_X_SurfCont *DOCont;/*!< Displayable object controller */
+   #endif 
+   SUMA_PICK_RESULT *PR;
+   #if 0 /* Not in use yet*/
+   SUMA_OVERLAYS **Overlays;
+   int N_Overlays;
+   SUMA_Boolean *isColored; /*!< is the datum receiving color? Not masked say 
+                                 by thresholds etc. */
+   #endif
+} SUMA_SURF_SAUX;
+
+typedef struct {
+   float Eq[4];
+   int slc_num;
+   char variant[16];
+} SUMA_RENDERED_SLICE; /*!< Information about a rendered slice */
+
+/*! A volume object's Aux structure for SUMA's use */
+typedef struct {
+   DList *DisplayUpdates;
+   SUMA_X_SurfCont *DOCont;/*!< Displayable object controller */
+   SUMA_PICK_RESULT *PR;
+   SUMA_PICK_RESULT *PRc;
+   SUMA_OVERLAYS **Overlays;
+   int N_Overlays;
+   SUMA_Boolean *isColored; /*!< is the datum receiving color? Not masked say 
+                                 by thresholds etc. */
+   DList *slcl; /* Rendered slices, top slice rendered last */
+   DList *vrslcl;
+   int ShowAxSlc;
+   int ShowSaSlc;
+   int ShowCoSlc;
+   int ShowVrSlc;
+   
+   int SlicesAtCrosshair; /* Make three slices jump to location of crosshair */
+   SUMA_ATRANS_MODES TransMode; /*!< polygon transparency  */
+} SUMA_VOL_SAUX;
+
 #define SDSET_GSAUX(dset) ( ( (dset) && (dset)->Aux && (dset)->Aux->Saux &&   \
                                SUMA_isGraphDset(dset) ) ? \
                            (SUMA_GRAPH_SAUX *)((dset)->Aux->Saux):NULL )
+
 #define SDSET_GOVERLAY(dset) (( (dset) && (dset)->Aux && (dset)->Aux->Saux &&   \
                                SUMA_isGraphDset(dset) ) ? \
                   ((SUMA_GRAPH_SAUX *)(dset)->Aux->Saux)->Overlay:NULL )
-#define SDSET_GDRAW_VARIANT(dset) ( (SDSET_GSAUX(dset))->CurrentDrawVariant)
+                  
+#define SDSET_GMATSO(dset) (( (dset) && (dset)->Aux && (dset)->Aux->Saux &&   \
+                               SUMA_isGraphDset(dset) ) ? \
+                  ((SUMA_GRAPH_SAUX *)(dset)->Aux->Saux)->FrameSO:NULL )
+                  
+#define TDO_HAS_GRID(tdo) ( ((tdo) && (tdo)->net && (tdo)->net->grid) ? \
+                              (tdo)->net->grid : NULL )
+
+#define TDO_N_BUNDLES(tdo) ( ((tdo) && (tdo)->net ) ? (tdo)->net->N_tbv : -1 )
+#define TDO_N_TRACTS(tdo) ( ((tdo) ) ? Network_N_tracts((tdo)->net, 0) : -1 )
+
+#define TDO_BUNDLE(tdo, tbi) ( ((tdo) && (tdo)->net && (tdo)->net->tbv && \
+                                 tbi >= 0 && tbi < (tdo)->net->N_tbv) ? \
+                                                   (tdo)->net->tbv[tbi] : NULL )
+#define TDO_TSAUX(tdo) ( (tdo) ? (SUMA_TRACT_SAUX *)(tdo)->Saux:NULL )
+#define VDO_VSAUX(vo) ( (vo) ? (SUMA_VOL_SAUX *)(vo)->Saux:NULL )
+#define SDO_SSAUX(so) ( (so) ? (SUMA_SURF_SAUX *)(so)->Saux:NULL )
+#define MDO_MSAUX(mo) ( (mo) ? (SUMA_MASK_SAUX *)(mo)->Saux:NULL )
+
+#define VE_NX(ve) SUMA_VE_Ni(&ve, 0)
+#define VE_NY(ve) SUMA_VE_Nj(&ve, 0)
+#define VE_NZ(ve) SUMA_VE_Nk(&ve, 0)
+#define VE_NXY(ve) SUMA_VE_Niy(&ve, 0)
+#define VE_NVOX(ve) SUMA_VE_Nvox(&ve, 0)
+
+#define VO_NI(vo) ( (vo) ?  \
+                        SUMA_VE_Ni((vo)->VE, 0) : -1 )
+#define VO_NIJ(vo) ( (vo) ?  \
+                        SUMA_VE_Nij((vo)->VE, 0) : -1 )
+#define VO_NJ(vo) ( (vo) ?  \
+                        SUMA_VE_Nj((vo)->VE, 0) : -1 )
+#define VO_NK(vo) ( (vo) ?  \
+                        SUMA_VE_Nk((vo)->VE, 0) : -1 )
+#define VO_NVOX(vo) ( (vo)  ?  \
+                        SUMA_VE_Nvox((vo)->VE, 0) : -1 )
+#define VO_N_VOLS(vo) ( SUMA_VO_NumVE(vo) )
+
+#define MDO_IS_SHADOW(MDO) ( ((MDO) && (MDO)->mtype[0] == 'C' && \
+                                       (MDO)->mtype[1] == 'A' && \
+                                       (MDO)->mtype[2] == 'S' && \
+                                       (MDO)->mtype[3] == 'P' && \
+                                       (MDO)->mtype[4] == 'E' && \
+                                       (MDO)->mtype[5] == 'R' && \
+                                       (MDO)->mtype[6] == '\0' ) ? 1:0 )
+#define MDO_IS_BOX(MDO) ( ((MDO) && (!strcasecmp((MDO)->mtype,"box") || \
+                                     !strcasecmp((MDO)->mtype,"cube"))) ? 1:0 )
+#define MDO_IS_SPH(MDO) ( ((MDO) && (!strcasecmp((MDO)->mtype,"ball") || \
+                                     !strcasecmp((MDO)->mtype,"sphere"))) ? 1:0 )
+#define MDO_IS_SURF(MDO) ( ((MDO) && (!strcasecmp((MDO)->mtype,"surf"))) ? 1:0 )
 
 SUMA_Boolean SUMA_DrawDO_UL_FullMonty(DList *dl);
 SUMA_Boolean SUMA_ADO_UL_Add(SUMA_ALL_DO *ado, char *com, int replace);
@@ -79,7 +212,16 @@ DListElmt *SUMA_DrawDO_UL_Find(DList *dl, char *com);
 SUMA_Boolean SUMA_DrawDO_UL_EmptyList(DList *dl, DListElmt *del);
 SUMA_Boolean SUMA_DestroyNgrHashDatum(SUMA_NGR_INDEX_HASH_DATUM *thd);
 void SUMA_Free_GSaux(void *vSaux);
+void SUMA_Free_SSaux(void *vSaux);
+void SUMA_Free_TSaux(void *vSaux);
+void SUMA_Free_MSaux(void *vSaux);
+void SUMA_Free_VSaux(void *vSaux);
 void SUMA_Free_Saux_DisplayUpdates_datum(void *ddd);
+SUMA_Boolean SUMA_AddTractSaux(SUMA_TractDO *tdo);
+float SUMA_TDO_tract_length(SUMA_TractDO *tdo, int tt);
+SUMA_Boolean SUMA_AddVolSaux(SUMA_VolumeObject *vo);
+void SUMA_Free_SliceListDatum(void *data);
+SUMA_Boolean SUMA_AddMaskSaux(SUMA_MaskDO *mdo);
 SUMA_Boolean SUMA_AddDsetSaux(SUMA_DSET *dset);
 SUMA_Boolean SUMA_Load_Dumb_DO(SUMA_ALL_DO *ado, SUMA_DUMB_DO *DDO);
 SUMA_Boolean SUMA_SetDrawVariant(SUMA_DSET *dset, char *variant);
@@ -87,7 +229,11 @@ char *SUMA_GetDrawVariant(SUMA_DSET *dset);
 SUMA_Boolean SUMA_UnSetDrawVariant(SUMA_DSET *dset);
 SUMA_Boolean SUMA_SetDrawVariant(SUMA_DSET *dset, char *variant);
 SUMA_Boolean SUMA_isDrawVariant(SUMA_DSET *dset, char *variant);
-float *SUMA_Graph_NodeList(SUMA_DSET *dset, int *N_Node, int recompute,    
+int SUMA_GDSET_edgeij_to_GMATRIX_XYZ(SUMA_DSET *dset, 
+                                        int ei, int ej, float *XYZ, int FC);
+int SUMA_GDSET_GMATRIX_CellPixSize(SUMA_DSET *dset, SUMA_SurfaceViewer *sv,
+                                   float *Sz);
+float *SUMA_GDSET_NodeList(SUMA_DSET *dset, int *N_Node, int recompute,    
                            int **ind, char *thisvariant); 
 NI_element * SUMA_SO_NIDO_Node_Texture (  SUMA_SurfaceObject *SO, SUMA_DO* dov, 
                                           int N_do, SUMA_SurfaceViewer *sv );
@@ -125,7 +271,7 @@ float *SUMA_VisX_CoordPointer(SUMA_SurfaceObject *SO);
 SUMA_Boolean SUMA_VisX_Pointers4Display(SUMA_SurfaceObject *SO, int fordisp);
 int SUMA_AllowPrying(SUMA_SurfaceViewer *sv, int *RegSO);
 SUMA_Boolean SUMA_ResetPrying(SUMA_SurfaceViewer *svu);
-SUMA_Boolean SUMA_ApplyPrying(SUMA_SurfaceViewer *sv, float val, char *units,
+SUMA_Boolean SUMA_ApplyPrying(SUMA_SurfaceViewer *sv, float val[3], char *units,
                               int recompute_norm);
 SUMA_Boolean SUMA_RecomputeNormsPrying(SUMA_SurfaceViewer *svu);
 int SUMA_LeftShownOnLeft(SUMA_SurfaceViewer *sv, 
@@ -152,7 +298,9 @@ char *SUMA_VisX_Info(SUMA_VIS_XFORM VisX, int N_Node, char *mumble);
 char *SUMA_SurfaceObject_Info (SUMA_SurfaceObject *SO, DList *DsetList);
 char *SUMA_ADO_Info(SUMA_ALL_DO *ado, DList *DsetList, int detail);
 SUMA_SurfaceObject *SUMA_Alloc_SurfObject_Struct(int N);
-int SUMA_NumVE(SUMA_VolumeObject *VO);
+int SUMA_VO_NumVE(SUMA_VolumeObject *VO);
+SUMA_DSET *SUMA_VO_dset(SUMA_VolumeObject *VO);
+SUMA_DSET *SUMA_VE_dset(SUMA_VolumeElement **VE, int idset);
 SUMA_VolumeObject *SUMA_CreateVolumeObject(char *label);
 SUMA_Boolean SUMA_AddDsetVolumeObject( SUMA_VolumeObject *VO, 
                                        THD_3dim_dataset **dsetp);
@@ -168,6 +316,50 @@ SUMA_Boolean SUMA_Draw_SO_ROI (SUMA_SurfaceObject *SO, SUMA_DO* dov, int N_dov,
 SUMA_Boolean SUMA_Draw_SO_Dset_Contours(SUMA_SurfaceObject *SO, 
                                SUMA_SurfaceViewer *sv);
 SUMA_DO_Types SUMA_Guess_DO_Type(char *s);
+SUMA_MaskDO *SUMA_SymMaskDO(char *s, char *mtype, char *hid, byte mtypeonly);
+SUMA_Boolean SUMA_MDO_OkVarName(char *this);
+SUMA_Boolean SUMA_MDO_SetVarName(SUMA_MaskDO *mdo, char *this);
+SUMA_MaskDO *SUMA_MDO_GetVar(char *vn);
+SUMA_Boolean SUMA_AccessorizeMDO(SUMA_MaskDO *MDO);
+SUMA_Boolean SUMA_isSymMaskDO(char *s, char *mtype);
+SUMA_Boolean SUMA_Ok_Sym_MaskDO_Type(char *mtype);
+SUMA_Boolean SUMA_Guess_Str_MaskDO_Type(char *s, char *mtype);
+SUMA_Boolean SUMA_Set_MaskDO_Type(SUMA_MaskDO *mdo, char *mtype);
+SUMA_Boolean SUMA_Set_MaskDO_Cen(SUMA_MaskDO *mdo, float *cen);
+SUMA_Boolean SUMA_Set_MaskDO_Dim(SUMA_MaskDO *mdo, float *dim);
+SUMA_Boolean SUMA_Set_MaskDO_Trans(SUMA_MaskDO *mdo, SUMA_TRANS_MODES T);
+SUMA_Boolean SUMA_Set_MaskDO_Alpha(SUMA_MaskDO *mdo, float alpha);
+SUMA_Boolean SUMA_Set_MaskDO_Color(SUMA_MaskDO *mdo, float *col, float dim);
+SUMA_Boolean SUMA_Set_MaskDO_Label(SUMA_MaskDO *mdo, char *lab);
+#define SUMA_MDO_New_Cen(mdo, cen) \
+            SUMA_MDO_New_Params((mdo), (cen), NULL, NULL, NULL, NULL, \
+                                 -1, STM_N_TransModes, -1)
+#define SUMA_MDO_New_Type(mdo, ttype) \
+            SUMA_MDO_New_Params((mdo), NULL, NULL, NULL, NULL, (ttype), \
+                                 -1, STM_N_TransModes, -1)
+#define SUMA_MDO_New_Label(mdo, ttype) \
+            SUMA_MDO_New_Params((mdo), NULL, NULL, NULL, (ttype), NULL, \
+                                 -1, STM_N_TransModes, -1)
+#define SUMA_MDO_New_Dim(mdo, dim) \
+            SUMA_MDO_New_Params((mdo), NULL, (dim), NULL, NULL, NULL, \
+                                 -1, STM_N_TransModes, -1)
+#define SUMA_MDO_New_Color(mdo, col) \
+            SUMA_MDO_New_Params((mdo), NULL, NULL, (col), NULL, NULL, \
+                                 -1, STM_N_TransModes, -1)
+#define SUMA_MDO_New_Trans(mdo, tran) \
+            SUMA_MDO_New_Params((mdo), NULL, NULL, NULL, NULL, NULL, \
+                                 -1, tran, -1)
+#define SUMA_MDO_New_Alpha(mdo, alpha) \
+            SUMA_MDO_New_Params((mdo), NULL, NULL, NULL, NULL, NULL, \
+                                 alpha, STM_N_TransModes, -1)
+#define SUMA_MDO_New_CDim(mdo, cdim) \
+            SUMA_MDO_New_Params((mdo), NULL, NULL, NULL, NULL, NULL, \
+                                 -1, STM_N_TransModes, cdim)
+int SUMA_MDO_New_Doppel(SUMA_MaskDO *mdo, float *xyz);
+int SUMA_MDO_New_parent(SUMA_MaskDO *mdo, char *parent_id, int parent_datum_id);
+int SUMA_MDO_New_Params(SUMA_MaskDO *mdo, float *cen, float *dim, 
+                        float *col, char *Label, char *Type,
+                        float alpha, SUMA_TRANS_MODES tran, float cdim);
 SUMA_NIDO * SUMA_Alloc_NIDO (char *idcode_str, char *Label, 
                              char *Parent_idcode_str);
 SUMA_NIDO *SUMA_free_NIDO(SUMA_NIDO *NIDO); 
@@ -179,16 +371,49 @@ SUMA_SegmentDO * SUMA_Alloc_SegmentDO (int N_n, char *Label, int oriented,
                                       int NodeBased, SUMA_DO_Types type, 
                                     SUMA_DO_Types P_type, char *DrawnDO_variant);
 void SUMA_free_SegmentDO (SUMA_SegmentDO * SDO);
+SUMA_MaskDO *SUMA_Alloc_MaskDO ( int N_obj, char *Label, char *hash_label,
+                                 char *parent_ADO_id, 
+                                 int withcol);
+void SUMA_free_MaskDO (SUMA_MaskDO * MDO);
+int SUMA_Set_N_SegNodes_SegmentDO(SUMA_SegmentDO * SDO, int N);
+int SUMA_Set_N_AllNodes_SegmentDO(SUMA_SegmentDO * SDO, int N);
 SUMA_Boolean SUMA_DrawSegmentDO (SUMA_SegmentDO *SDO, SUMA_SurfaceViewer *sv);
 SUMA_Boolean SUMA_DrawGSegmentDO (SUMA_GRAPH_SAUX *GSaux, 
                                   SUMA_SurfaceViewer *sv);
 SUMA_Boolean SUMA_DrawTractDO (SUMA_TractDO *TDO, SUMA_SurfaceViewer *sv);
+SUMA_Boolean SUMA_DrawMaskDO (SUMA_MaskDO *MDO, SUMA_SurfaceViewer *sv);
+float *SUMA_ADO_Center(SUMA_ALL_DO *ado, float *here);
+float *SUMA_ADO_Range(SUMA_ALL_DO *ado, float *here);
+float *SUMA_TDO_Grid_Center(SUMA_TractDO *tdo, float *here);
+float *SUMA_MDO_Center(SUMA_MaskDO *MDO, float *here);
+float *SUMA_VO_Grid_Center(SUMA_VolumeObject *vo, float *here);
+int SUMA_TDO_N_tracts(SUMA_TractDO *tdo);
+int SUMA_TDO_Max_N_tracts(SUMA_TractDO *tdo); 
+int SUMA_VE_Nk(SUMA_VolumeElement **VE, int ivo); 
+int SUMA_VE_Nj(SUMA_VolumeElement **VE, int ivo);
+int SUMA_VE_Ni(SUMA_VolumeElement **VE, int ivo);
+int SUMA_VE_Niy(SUMA_VolumeElement **VE, int ivo);
+int SUMA_VE_Nvox(SUMA_VolumeElement **VE, int ivo);
+int SUMA_VO_N_Slices(SUMA_VolumeObject *VO, char *variant);
+int SUMA_VE_N_Slices(SUMA_VolumeElement **VE, int ivo, char *variant);
+char * SUMA_VO_orcode(SUMA_VolumeObject *VO);
+char *SUMA_VE_orcode(SUMA_VolumeElement **VE, int ivo);
+char * SUMA_VE_Headname(SUMA_VolumeElement **VE, int ivo);
+SUMA_Boolean SUMA_VE_Set_Dims(SUMA_VolumeElement **VE, int ive);
+float *SUMA_TDO_Points_Center(SUMA_TractDO *tdo, float *here);
+float *SUMA_TDO_XYZ_Range(SUMA_TractDO *tdo, float *here);
+float *SUMA_VO_XYZ_Range(SUMA_VolumeObject *VO, float *here);
+float *SUMA_MDO_XYZ_Range(SUMA_MaskDO *MDO, float *here);
 SUMA_SphereDO * SUMA_Alloc_SphereDO (int N_n, char *Label, char *parent_idcode, 
                                      SUMA_DO_Types type);
 SUMA_TractDO * SUMA_Alloc_TractDO (char *Label, char *parent_idcode);
 SUMA_PlaneDO * SUMA_Alloc_PlaneDO (int N_n, char *Label, SUMA_DO_Types type);
 SUMA_Boolean SUMA_DrawGraphDO_G3D (SUMA_GraphLinkDO *gldo, 
                                    SUMA_SurfaceViewer *sv);
+SUMA_Boolean SUMA_BordFrac_to_GB(int BF, int *G, int *B);
+SUMA_NIDO * SUMA_GDSET_matrix_nido(SUMA_DSET *dset);
+SUMA_Boolean SUMA_GDSET_clear_matrix_nido(SUMA_DSET *dset, int clear_SO);
+SUMA_Boolean SUMA_GDSET_refresh_matrix_nido(SUMA_DSET *dset, int also_SO);
 SUMA_Boolean SUMA_DrawGraphDO_GMATRIX (SUMA_GraphLinkDO *gldo, 
                                        SUMA_SurfaceViewer *sv);
 SUMA_Boolean SUMA_DrawGraphDO_GRELIEF (SUMA_GraphLinkDO *gldo, 
@@ -222,8 +447,11 @@ char *SUMA_DO_state(SUMA_DO *DO);
 char *SUMA_iDO_group(int i);
 char *SUMA_DO_group(SUMA_DO *DO);
 int SUMA_isDO_AnatCorrect(SUMA_DO *DO);
+int  SUMA_is_iDO_AnatCorrect(int dov_id);
 SUMA_Boolean SUMA_DrawSphereDO (SUMA_SphereDO *SDO, SUMA_SurfaceViewer *sv);
 SUMA_Boolean SUMA_DrawPlaneDO (SUMA_PlaneDO *SDO, SUMA_SurfaceViewer *sv);
+SUMA_Boolean SUMA_DrawPlanes( float **PlEq, float **cen, float *sz, 
+                              int N_pl, SUMA_SurfaceViewer *sv);
 SUMA_Boolean SUMA_isROIdequal (SUMA_ROI_DATUM *ROId1, SUMA_ROI_DATUM *ROId2);
 void SUMA_FreeROIDatum (void * data);
 SUMA_ROI_DATUM * SUMA_AllocROIDatum (void);
@@ -258,11 +486,15 @@ SUMA_DRAWN_ROI * SUMA_1DROI_to_DrawnROI ( int *Node, int N_Node, int Value,
 SUMA_SegmentDO * SUMA_ReadNBVecDO (char *s, int oriented, char *parent_SO_id);
 SUMA_SphereDO * SUMA_ReadNBSphDO (char *s, char *parent_SO_id);
 SUMA_TractDO *SUMA_ReadTractDO(char *s, char *parent_SO_id);
+SUMA_TractDO *SUMA_Net2TractDO(TAYLOR_NETWORK *net, char *Label, 
+                               char *parent_SO_id);
 GLushort SUMA_int_to_stipplemask(int i); 
+GLushort SUMA_int_to_stipplemask_cont(int i);
 SUMA_SegmentDO * SUMA_ReadSegDO (char *s, int oriented, char *soid);
 SUMA_SegmentDO * SUMA_ReadNBSegDO (char *s, int oriented, char *soid);
 SUMA_SphereDO * SUMA_ReadSphDO (char *s);
 SUMA_PlaneDO * SUMA_ReadPlaneDO (char *s);
+SUMA_MaskDO * SUMA_ReadMaskDO (char *s, char *parent_ADO_id);
 SUMA_NIDO *SUMA_ReadNIDO(char *s, char *soid);
 SUMA_NIDO *SUMA_BlankNIDO (char *idcode_str, char *Label, 
                            char *parent_so_id, char *coord_type,
@@ -280,7 +512,7 @@ SUMA_SegmentDO *SUMA_CreateSegmentDO(  int N_n, int oriented, int NodeBased,
 SUMA_DO * SUMA_Multiply_NodeObjects ( SUMA_SurfaceObject *SO, 
                                       SUMA_DO *DO );
 SUMA_NIDO ** SUMA_Multiply_NodeNIDOObjects ( SUMA_SurfaceObject *SO, 
-                                      SUMA_DO *DO );
+                                      SUMA_DO *DO, int *NodeID, int N_Node);
 SUMA_Boolean SUMA_ApplyDataToNodeObjects(
             SUMA_SurfaceObject *SurfObj, SUMA_SurfaceViewer *sv);
 SUMA_SurfaceObject *SUMA_Cmap_To_SO (SUMA_COLOR_MAP *Cmap, float orig[3], 
@@ -312,7 +544,8 @@ SUMA_Boolean SUMA_DrawSphereNIDOnel(  NI_element *nel,
                                     float *default_txcol, int default_node, 
                                     SUMA_SurfaceViewer *sv) ;
 SUMA_Boolean SUMA_DrawNIDO (SUMA_NIDO *SDO, SUMA_SurfaceViewer *sv);
-SUMA_Boolean SUMA_DrawLineAxis ( SUMA_AxisSegmentInfo *ASIp, SUMA_Axis *Ax, SUMA_Boolean AddText);
+SUMA_Boolean SUMA_DrawLineAxis ( SUMA_AxisSegmentInfo *ASIp, SUMA_Axis *Ax, 
+                                 SUMA_Boolean AddText);
 DList *SUMA_SortedAxisSegmentList ( SUMA_SurfaceViewer *sv, SUMA_Axis *Ax, 
                                     SUMA_SORT_BOX_AXIS_OPTION opt);
 void SUMA_WorldAxisStandard (SUMA_Axis* Ax, SUMA_SurfaceViewer *sv);
@@ -321,6 +554,11 @@ SUMA_Boolean SUMA_DrawText(char *txt, float *Ps);
 void SUMA_ReportDrawnROIDatumLength(SUMA_SurfaceObject *SO, SUMA_ROI_DATUM *ROId, FILE *out, SUMA_WIDGET_INDEX_DRAWROI_WHATDIST option);
 SUMA_SurfaceObject *SUMA_HJS_Surface(int ipart);
 SUMA_SurfaceObject *SUMA_head_01_surface(void);
+SUMA_SurfaceObject *SUMA_cube_surface(float sz, float *cen);
+SUMA_SurfaceObject *SUMA_box_surface(float *sz3, float *cen, 
+                                     float *col, int n_obj);
+SUMA_SurfaceObject *SUMA_ball_surface(float *hd3, float *cen, float *col, 
+                                     int n_obj);
 NI_group *SUMA_SDO2niSDO(SUMA_SegmentDO *SDO);
 SUMA_SegmentDO *SUMA_niSDO2SDO(NI_group *ngr); 
 SUMA_Boolean SUMA_isSODimInitialized(SUMA_SurfaceObject *SO) ;
@@ -329,7 +567,12 @@ SUMA_Boolean SUMA_SetSODims(SUMA_SurfaceObject *SO);
 SUMA_Boolean SUMA_MinMaxNodesInROI (SUMA_DRAWN_ROI *D_ROI, 
                                     int MinMax[]);
 SUMA_Boolean SUMA_TextBoxSize(char *txt, int *w, int *h, int *nl, void *font);
+byte *SUMA_WordOverlapMask(int Nwidth, int Nheight, int N_n, char **names, 
+                           void *fontGL, float *xyz, float maxoverlap, 
+                           byte *usethesewords);
+int SUMA_WordBoxSize (char **txt, int N_txt, int *w, void *font);
 int SUMA_glutBitmapFontHeight(void *font) ;
+int *SUMA_NIDOtext_LineWidth(char *string, void *font, int *N_lines);
 
 static void *FontPointerList[] = 
          {  GLUT_BITMAP_8_BY_13, GLUT_BITMAP_9_BY_15, 
@@ -345,7 +588,8 @@ int SUMA_NodeRange_DrawnROI (SUMA_DRAWN_ROI *ROI, int *min, int *max);
 int SUMA_NIDO_TexEnvMode(NI_element *nel, int def);
 const GLubyte *SUMA_StippleMask(int transp);
 const GLubyte *SUMA_StippleMask_rand(int transp);
-const GLubyte *SUMA_StippleMask_shift(int transp);
+const GLubyte *SUMA_StippleMask_shift(int transp, int btp);
+GLushort SUMA_StippleLineMask_rand(int transp, int chunkwidth, int rseed);
 void SUMA_StippleMaskResest(void);
 SUMA_GL_STEL *SUMA_FindStateTrackEl(char *state, DList *stu);
 void SUMA_FreeStateTrackEl(void *stel);
@@ -366,7 +610,9 @@ GLubyte *SUMA_DO_get_pick_colid(SUMA_ALL_DO *DO, char *idcode_str,
                                    SUMA_SurfaceViewer *sv);
 NI_element *SUMA_GDSET_Edge_Bundle(SUMA_DSET *gset, SUMA_GRAPH_SAUX *GSaux, 
                                    int edge_id, int alt_edge_id);
-                                   
+NI_group *SUMA_MDO_to_NIMDO(SUMA_MaskDO *mdo, NI_group *cont);
+SUMA_MaskDO *SUMA_NIMDO_to_MDO(NI_group *);
+     
 /*! Following DO_ macros are for setting states up for colorid picking
     and restoring states at exit.
     Note that some of these are overkill. They were added in a attempt
