@@ -246,6 +246,7 @@ static mday holiday[] = {
    {FEB,10,"St. Scholastica's day"                                   } ,
    {FEB,10,"Anniversary of Treaty of Paris, 1763"                    } ,
    {FEB,11,"Josiah Willard Gibb's birthday"                          } ,
+   {FEB,11,"Seoul (Hanyang U) Bootcamp Anniversary"                  } ,
    {FEB,11,"Thomas Edison's birthday"                                } ,
    {FEB,11,"Iran National Day"                                       } ,
    {FEB,12,"Abraham Lincoln's birthday"                              } ,
@@ -320,6 +321,7 @@ static mday holiday[] = {
    {APR,10,"Anniversary of loss of USS Thresher"                     } ,
    {APR,10,"National Sibling Day (USA)"                              } ,
    {APR,11,"Dean Acheson's birthday"                                 } ,
+   {APR,11,"Tulsa Bootcamp Anniversary"                              } ,
    {APR,12,"Anniversary of Yuri Gagarin's spaceflight"               } ,
    {APR,13,"Thomas Jefferson's birthday"                             } ,
    {APR,13,"New Year's Day (SE Asia)"                                } ,
@@ -331,6 +333,7 @@ static mday holiday[] = {
    {APR,17,"Syria Independence Day"                                  } ,
    {APR,18,"Anniversary of Paul Revere's Ride"                       } ,
    {APR,19,"Anniversary of Warsaw Ghetto Uprising"                   } ,
+   {APR,19,"Chongqing SWU Bootcamp Anniversary"                      } ,
    {APR,21,"Queen Elizabeth II's birthday"                           } ,
    {APR,22,"Earth Day"                                               } ,
    {APR,22,"Sir Michael Atiyah's birthday"                           } ,
@@ -402,6 +405,7 @@ static mday holiday[] = {
    {MAY,30,"St. Jeanne d'Arc's day"                                  } ,
    {MAY,31,"Walt Whitman's birthday"                                 } ,
    {MAY,31,"South Africa Republic Day"                               } ,
+   {MAY,31,"Pisa Bootcamp Anniversary"                               } ,
 
    {JUN, 1,"Marilyn Monroe's birthday"                               } ,
    {JUN, 1,"Tunisia National Day"                                    } ,
@@ -410,6 +414,7 @@ static mday holiday[] = {
    {JUN, 5,"John Maynard Keynes' birthday"                           } ,
    {JUN, 5,"Seychelles Independence Day"                             } ,
    {JUN, 6,"D-Day"                                                   } ,
+   {JUN, 6,"Pisa Bootcamp Anniversary"                               } ,
    {JUN, 7,"Imre Nagy's birthday"                                    } ,
    {JUN, 8,"Frank Lloyd Wright's birthday"                           } ,
    {JUN, 9,"Anniversary of Donald Duck's debut"                      } ,
@@ -530,6 +535,7 @@ static mday holiday[] = {
    {AUG,11,"Anniversary of Alcatraz Prison"                          } ,
    {AUG,11,"Anniversary of Battle of Thermopylae"                    } ,
    {AUG,12,"Erwin Schrodinger's birthday"                            } ,
+   {AUG,12,"World Elephant Day"                                      } ,
    {AUG,14,"Pakistan Independence Day"                               } ,
    {AUG,15,"Napoleon's birthday"                                     } ,
    {AUG,15,"India Independence Day"                                  } ,
@@ -611,6 +617,7 @@ static mday holiday[] = {
    {OCT, 2,"Groucho Marx's birthday"                                 } ,
    {OCT, 3,"Anniversary of reunification of Germany"                 } ,
    {OCT, 4,"Anniversary of Sputnik launch"                           } ,
+   {OCT, 4,"Houston Bootcamp Anniversary"                            } ,
    {OCT, 6,"Anniversary of attack on Frodo at Weathertop"            } ,
    {OCT, 9,"Alfred Dreyfus's birthday"                               } ,
    {OCT,10,"Anniversary of Battle of Tours"                          } ,
@@ -634,6 +641,7 @@ static mday holiday[] = {
    {OCT,29,"Turkey Republic Day"                                     } ,
    {OCT,29,"Anniversary of Black Tuesday"                            } ,
    {OCT,30,"Anniversary of the War of the Worlds!"                   } ,
+   {OCT,30,"Seoul SNUH Bootcamp Anniversary"                         } ,
    {OCT,31,"Halloween"                                               } ,
    {OCT,31,"John Keats' birthday"                                    } ,
    {OCT,31,"Karl Weierstrass's birthday"                             } ,
@@ -658,6 +666,7 @@ static mday holiday[] = {
    {NOV, 8,"Felix Haussdorf's birthday"                              } ,
    {NOV, 8,"Katherine Hepburn's birthday"                            } ,
    {NOV, 9,"Benjamin Banneker's birthday"                            } ,
+   {NOV, 9,"Tainan NCKU Bootcamp Anniversary"                        } ,
    {NOV, 9,"Cambodia Independence Day"                               } ,
    {NOV,10,"Martin Luther's birthday"                                } ,
    {NOV,10,"Founding of US Marine Corps (1775)"                      } ,
