@@ -625,6 +625,13 @@ static char *helpstring =
    "             will be used.  When you change the time 'Index' in AFNI,\n"
    "             InstaCalc will NOT be automatically updated -- you still have\n"
    "             to press 'Compute InstaCalc' to get A_ICALC re-computed.\n"
+   " * Pre-defined variables (if not set as described above) are\n"
+   "     x = DICOM x coordinate (R=- L=+)\n"
+   "     y = DICOM y coordinate (A=- P=+)\n"
+   "     z = DICOM z coordiante (I=- S=+)\n"
+   "     i = #1 3D index  j = #2 3D index  k = #3 3D index\n"
+   "   You can use these variable names in the expression without defining them\n"
+   "   in the variable choosers.\n"
    "\n"
    "Author -- RW Cox -- Sep 2009\n"
    "\n"
