@@ -64,7 +64,7 @@ typedef struct {
 extern "C" {
 #endif
 
-extern MCW_bbox * new_MCW_bbox( Widget , int , char * lab[] , int , int ,
+extern MCW_bbox * new_MCW_bbox( Widget , int , char *lab[] , int , int ,
                                 XtCallbackProc , XtPointer ) ;
 
 extern void MCW_set_bbox( MCW_bbox * , int ) ;
@@ -87,6 +87,7 @@ typedef char * str_func() ;
 typedef struct {
       Widget wrowcol ,                   /* Container */
              wlabel , wdown,wup , wtext ;/* left-to-right widgets */
+      Widget wname ;
 
       Widget wmenu ;                     /* for optmenu style only! */
       int block_assign_actions ;
@@ -94,7 +95,7 @@ typedef struct {
       int ival , imin,imax , decimals ;  /* value, min & max, decim shift */
       float fval , fmin,fmax ;           /* float values (includes decim) */
 
-      char * sval ;        /* current string value from TextField */
+      char *sval ;        /* current string value from TextField */
 
       int old_ival ;       /* values just before the last change */
       float old_fval ;
@@ -115,7 +116,7 @@ typedef struct {
 
       XtPointer parent , aux ;
 
-      float fstep ;  /* 16 Feb 1999 */
+      float fstep ;                    /* 16 Feb 1999 */
       int optmenu_call_if_unchanged ;  /* 10 Oct 2007 */
 } MCW_arrowval ;
 
@@ -236,6 +237,13 @@ extern char * MCW_av_substring_CB( MCW_arrowval * , XtPointer ) ;
 
 /*---------------------------------------------------------------------------------*/
 
+#define MSTUF_END     0
+#define MSTUF_NONE    0
+#define MSTUF_INT     1
+#define MSTUF_INTEGER 1
+#define MSTUF_STRING  2
+#define MSTUF_STRLIST 3
+
 #define POPDOWN_ovcolor_chooser    MCW_choose_ovcolor(NULL,NULL,0,NULL,NULL)
 #define POPDOWN_string_chooser     MCW_choose_string(NULL,NULL,NULL,NULL,NULL)
 #define POPDOWN_strlist_chooser    MCW_choose_strlist(NULL,NULL,0,0,NULL,NULL,NULL)
@@ -246,12 +254,18 @@ extern char * MCW_av_substring_CB( MCW_arrowval * , XtPointer ) ;
 #define POPDOWN_editable_strlist_chooser \
                                    MCW_choose_editable_strlist(NULL,NULL,NULL,0,NULL,NULL)
 
+#define POPDOWN_stuff_chooser      MCW_choose_stuff(NULL,NULL,NULL,NULL,0)
+
 extern void MCW_list_mode_CB( MCW_arrowval * , XtPointer ) ;
 
 extern char * MCW_DC_ovcolor_text( MCW_arrowval * , MCW_DC * ) ;
 extern void   MCW_choose_ovcolor( Widget , MCW_DC * , int , gen_func * , XtPointer ) ;
 extern void   MCW_choose_CB( Widget , XtPointer , XtPointer ) ;
 
+extern void MCW_choose_stuff( Widget wpar , char *mainlabel ,
+                              gen_func *func , XtPointer func_data , ... ) ;
+extern void MCW_stuff_CB( Widget w , XtPointer client_data , XtPointer call_data ) ;
+
 extern void   MCW_destroy_chooser_CB( Widget , XtPointer , XtPointer ) ;
 extern void   MCW_kill_chooser_CB   ( Widget , XtPointer , XtPointer ) ;
 
