@@ -12,7 +12,7 @@
     Output = statistic's value.
 *//*------------------------------------------------------------------------*/
 
-float mri_nstat( int code , int npt , float *far , float voxval)
+float mri_nstat( int code , int npt , float *far , float voxval )
 {
    register float outval ; float val ;
 
@@ -818,6 +818,8 @@ ENTRY("THD_localstat") ;
          ERROR_exit("Failed to reduce output grid");
       }
       DSET_delete(oset) ; oset = tout; tout = NULL;
+      /* apply mask to resampled output */
+      if (mask) THD_applydsetmask(oset,mask);
    }
    RETURN(oset) ;
 }
