@@ -6,7 +6,7 @@
 	threshold to make GM-ROIs; then that latter and make into ROIs for
 	tractography (most likely prob. tractography to define WM-ROIs)
 
-	Inflation/detection for voxels sharing face/edge, but not only
+	Inflation/detection for voxels sharing face/edge, but not for only
 	vertex.
 
 	Dec. 2012: 
@@ -16,6 +16,15 @@
 
 	Jan. 2013:
 	     csf_skel option
+
+   Sept. 2013:
+        allow negative ROIs to be used in refset
+
+   Apr. 2014:
+        can redefine how tight the definition of neighbors is
+        also put in HOT_POINTS option:  threshold based on vol to get
+        max values.
+        --> bug fixed version; forgot a logical test in IF statement 
 */
 
 
@@ -27,17 +36,27 @@
 #include <mrilib.h>    
 #include <rsfc.h>    
 #include <3ddata.h>    
+#include <gsl/gsl_rng.h>
 #include "DoTrackit.h"
 
 #define DEP (1)              // search rad of defining ROIs
 #define BASE_DVAL (-1)       // intermed values for ROI-finding
 #define ALLOWED_NROI (150)   // buffer size for array of refset...
 
+int compfunc_desc(const void * a, const void * b) 
+{
+   return (*(float*)b > *(float*)a) - (*(float*)a > *(float*)b);
+}
+
 void usage_ROIMaker(int detail) 
 {
 	printf(
 "\n"
-"  ROIMaker, written by PA Taylor (Nov, 2012).\n\n"
+"  ROIMaker, written by PA Taylor (Nov, 2012), part of FATCAT (Taylor & Saad,\n"
+"  2013) in AFNI.\n"
+"\n"
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
+"\n"
 "  THE GENERAL PURPOSE of this code is to create a labelled set of ROIs from\n"
 "  input data. It was predominantly written with a view of aiding the process\n"
 "  of combining functional and tractographic/structural data. Thus, one might\n"
@@ -54,7 +73,9 @@ void usage_ROIMaker(int detail)
 "  and/or input a white matter skeleton (such as could be defined from a \n"
 "  segmented T1 image or an FA map) and use this as an additional guide for\n"
 "  inflating the GM ROIs.  The output of this program can be used directly\n"  
-"  for guiding tractography, such as with 3dProbTrackID.\n"
+"  for guiding tractography, such as with 3dTrackID.\n"
+"\n"
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
 "\n"
 "  OUTPUTS:\n"
 "   + `GM' map of ROIs  :based on value- and volume-thresholding, would\n"
@@ -87,12 +108,18 @@ void usage_ROIMaker(int detail)
 "                       with multiple REFSET ROIs, then the former is split\n"
 "                       amongst the latter-- overlap regions get labelled \n"
 "                       first, and then REFSET labels grow to cover the INSET\n"
-"                       ROI in question.\n"
+"                       ROI in question.  NB: it is possible to utilize\n"
+"                       negative-valued ROIs (voxels =-1) to represent NOT-\n"
+"                       regions for tracking, for example.\n"
 "     -volthr   MINVOL :integer number representing minimum size a cluster of\n"
 "                       voxels must have in order to remain a GM ROI after \n"
 "                       the values have been thresholded.  Number might be\n"
 "                       estimated with 3dAlphaSim, or otherwise, to reduce\n"
 "                       number of `noisy' clusters.\n"
+"     -only_some_top N :after '-volthr' but before any ref-matching or\n"
+"                       inflating, one can restrict each found region\n"
+"                       to keep only N voxels with the highest inset values.\n"
+"                       (If an ROI has <N voxels, then all would be kept.)\n"
 "     -inflate  N_INFL :number of voxels which with to pad each found ROI in\n"
 "                       order to turn GM ROIs into inflated (GMI) ROIs.\n"
 "                       ROIs won't overlap with each other, and a WM skeleton\n"
@@ -128,18 +155,44 @@ void usage_ROIMaker(int detail)
 "                       It's also useful to ensure that the output *_GMI*\n"
 "                       ROI masks stay within the brain-- this probably won't\n"
 "                       often matter too much.\n"
+"                       For an N-brick inset, one can input an N- or 1-brick\n"
+"                       mask.\n"
+"    -neigh_face_only  :can tighten the definition of neighbors, so that\n"
+"                       voxels must share a face to be grouped into same ROI\n"
+"                       (default is that neighbors share at least one edge).\n"
+"                       This should match up with default usage of the\n"
+"                       clusterize function in the AFNI window.\n"
+"    -neigh_upto_vert  :can loosen the definition of neighbors, so that\n"
+"                       voxels can be grouped into the same ROI if they share\n"
+"                       at least one vertex (see above for default).\n"
+"\n"
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
 "\n"
 "  + EXAMPLE:\n"
-"      3dROIMaker -inset CORR_VALUES+orig. -thresh 0.6 -prefix ROI_MAP \\\n"
-"            -volthr 100 -inflate 2 -wm_skel WM_T1+orig. -skel_stop .\n"
+"      3dROIMaker                     \\\n"
+"         -inset CORR_VALUES+orig.    \\\n"
+"         -thresh 0.6                 \\\n"
+"         -prefix ROI_MAP             \\\n"
+"         -volthr 100                 \\\n"
+"         -inflate 2                  \\\n"
+"         -wm_skel WM_T1+orig.        \\\n"
+"         -skel_stop \n"
 "\n"
-"\n");
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
+"\n"
+"  If you use this program, please reference the introductory/description\n"
+"  paper for the FATCAT toolbox:\n"
+"        Taylor PA, Saad ZS (2013).  FATCAT: (An Efficient) Functional\n"
+"        And Tractographic Connectivity Analysis Toolbox. Brain \n"
+"        Connectivity 3(5):523-535.\n"
+"____________________________________________________________________________\n"
+);
 	return;
 }
 
 
 int main(int argc, char *argv[]) {
-	int i,j,k,m,ii,jj,kk,mm,bb,n;
+	int i,j,k,m,ii,jj,kk,mm,bb,n,aaa;
 	int X,Y,Z;
 	int iarg=0;
 	THD_3dim_dataset *inset=NULL;
@@ -151,22 +204,28 @@ int main(int argc, char *argv[]) {
 	THD_3dim_dataset *insetCSF_SKEL=NULL;
 	THD_3dim_dataset *outsetGM=NULL, *outsetGMI=NULL;
 
+   int NEIGHBOR_LIMIT = 3; // default setting: neighbor shares face or
+                           // at least one edge
+
 	THD_3dim_dataset *MASK=NULL;
 	char in_mask[300];
 	int HAVE_MASK=0;
-
+   int HAVEPREFIX=0;
 
 	char in_REF[300];
 	char prefix_GM[300];
 	char prefix_GMI[300];
 	char voxel_order[4]="---";
 
+   float *fl_sort=NULL;
+
 	int HAVEREF = 0; // switch if an external ref file for ROI labels is present
 	int HAVESKEL = 0; // switch if an external ref file for ROI labels is present
 	int HAVE_CSFSKEL = 0; // similar to above...
 	int SKEL_STOP=0; // switch if inflation will be stopped in WM skeleton
 	int TRIM_OFF_WM=0; // switch if WM_skel will be used to trim initial input map
 	int idx = 0;
+   int count;
 	int VOLTHR = 0; // switch about thresholding GM ROI volume size
 	int val=0,Nvox=0;
 	int max_nroi=0, index1=0;
@@ -185,8 +244,10 @@ int main(int argc, char *argv[]) {
 	float SKEL_THR=0.5;// default, such as if input SKEL is a mask
 
 	int *Dim=NULL; 
-	int *NROI_IN=NULL,*NROI_IN_b=NULL,*INVROI_IN=NULL; // num of rois per brik, and inv labels
-	int **ROI_LABELS_REF=NULL, **INV_LABELS_REF=NULL; // allow labels to be non-consecutive.
+   // num of rois per brik, and inv labels
+	int *NROI_IN=NULL,*NROI_IN_b=NULL,*INVROI_IN=NULL;
+   // allow labels to be non-consecutive.
+	int **ROI_LABELS_REF=NULL, **INV_LABELS_REF=NULL; 
 	int *NROI_REF=NULL,*NROI_REF_b=NULL,*INVROI_REF=NULL;
 	int ****OLAP_RI=NULL; // info of overlap WRT ref and T inset
 	int **N_olap_RI=NULL,**N_olap_IR=NULL; // nums of rois per olap
@@ -198,6 +259,13 @@ int main(int argc, char *argv[]) {
 	int *NROI_GM=NULL,*INVROI_GM=NULL;
 	int ***COUNT_GM=NULL;
 
+   int HOT_POINTS=0;
+   float hot_val=0;
+
+   int *RESCALES=NULL; // will be used if negative values in refset mask
+   short int **temp_ref=NULL; // for holding rescaled values
+   THD_3dim_dataset *set_REFSCAL=NULL;
+   float dum1[1]={0},dum2[1]={0};
 
 	mainENTRY("3dROIMaker"); machdep(); 
   
@@ -207,7 +275,7 @@ int main(int argc, char *argv[]) {
 	// ****************************************************************
 	// ****************************************************************
 
-	//INFO_message("version: NU");
+	//INFO_message("version: OMICRON");
 	Dim = (int *)calloc(4,sizeof(int));
 
 	// scan args
@@ -258,6 +326,7 @@ int main(int argc, char *argv[]) {
 			if( !THD_filename_ok(prefix) ) 
 				ERROR_exit("Illegal name after '-prefix'");
 
+         HAVEPREFIX = 1;
 			iarg++ ; continue ;
 		}
 
@@ -290,6 +359,20 @@ int main(int argc, char *argv[]) {
 			iarg++ ; continue ;
 		}
 
+      if( strcmp(argv[iarg],"-only_some_top") == 0 ){
+			iarg++ ; if( iarg >= argc ) 
+							ERROR_exit("Need argument after '-only_some_top'");
+			HOT_POINTS = atoi(argv[iarg]);
+			
+			if(HOT_POINTS<=0)
+				ERROR_exit("The number of (high-value) voxels to keep per ROI=%d: must be >0!",
+							  HOT_POINTS);
+			
+			iarg++ ; continue ;
+		}
+
+      
+      
 		// can determine size of expansion based on this
 		if( strcmp(argv[iarg],"-inflate") == 0 ){
 			iarg++ ; if( iarg >= argc ) 
@@ -350,12 +433,20 @@ int main(int argc, char *argv[]) {
 			iarg++ ; continue ;
 		}
 
+		if( strcmp(argv[iarg],"-neigh_face_only") == 0) {
+			NEIGHBOR_LIMIT=2;
+			iarg++ ; continue ;
+		}
 
+		if( strcmp(argv[iarg],"-neigh_upto_vert") == 0) {
+			NEIGHBOR_LIMIT=4;
+			iarg++ ; continue ;
+		}
 
 		if( strcmp(argv[iarg],"-mask") == 0 ){
 			iarg++ ; if( iarg >= argc ) 
 							ERROR_exit("Need argument after '-mask'");
-			HAVE_MASK=1;
+			// HAVE_MASK=1;
 
 			sprintf(in_mask,"%s", argv[iarg]); 
 			MASK = THD_open_dataset(in_mask) ;
@@ -363,7 +454,8 @@ int main(int argc, char *argv[]) {
 				ERROR_exit("Can't open time series dataset '%s'.",in_mask);
 
 			DSET_load(MASK); CHECK_LOAD_ERROR(MASK);
-			
+			HAVE_MASK = DSET_NVALS(MASK);
+
 			iarg++ ; continue ;
 		}
 
@@ -381,15 +473,41 @@ int main(int argc, char *argv[]) {
 			ERROR_exit("The xyz-dimensions of refset and inset don't match");
 		
 		if( Dim[3] == HAVEREF )
-			INFO_message("Each subrik of refset will be applied to corresponding inset brik.");
+			INFO_message("Each subrik of refset will be applied to corresponding"
+                      " inset brik.");
 		else
-			ERROR_exit("The number of inset and refset briks must match: here, ref=%d, inset=%d",HAVEREF,Dim[3]);
+			ERROR_exit("The number of inset and refset briks must match: "
+                    " here, ref=%d, inset=%d",
+                    HAVEREF,Dim[3]);
 
 		if( voxel_order[0] != ORIENT_typestr[insetREF->daxes->xxorient][0] ||
 			 voxel_order[1] != ORIENT_typestr[insetREF->daxes->yyorient][0] ||
 			 voxel_order[2] != ORIENT_typestr[insetREF->daxes->zzorient][0] )
 			ERROR_exit("Refset orientation is not %s like the inset.",voxel_order);
 	}
+
+   if(HAVE_MASK) {
+		if((Dim[0] != DSET_NX(MASK)) || (Dim[1] != DSET_NY(MASK)) ||
+			(Dim[2] != DSET_NZ(MASK)) )
+			ERROR_exit("The xyz-dimensions of mask and inset don't match");
+		
+		if( Dim[3] == HAVE_MASK )
+			INFO_message("Each subrik of mask will be applied to corresponding "
+                      "inset brik.");
+      else if( HAVE_MASK == 1)
+         INFO_message("Will apply single mask to the multiple inset briks.");
+		else
+			ERROR_exit("The number of mask briks must be either one or match the"
+                    " number of inset briks.\n"
+                    "\t  Here: mask=%d, inset=%d",HAVE_MASK,Dim[3]);
+
+		if( voxel_order[0] != ORIENT_typestr[MASK->daxes->xxorient][0] ||
+			 voxel_order[1] != ORIENT_typestr[MASK->daxes->yyorient][0] ||
+			 voxel_order[2] != ORIENT_typestr[MASK->daxes->zzorient][0] )
+			ERROR_exit("Mask orientation is not %s like the inset.",voxel_order);
+	}
+
+
 	
 	if(HAVESKEL) {
 		if((Dim[0] != DSET_NX(insetSKEL)) || (Dim[1] != DSET_NY(insetSKEL)) ||
@@ -421,12 +539,16 @@ int main(int argc, char *argv[]) {
 
 
 	if( (!HAVESKEL) && SKEL_STOP) {
-		INFO_message("*+ You asked to stop inflation at the WM skeleton, but didn't give a skeleton using `-wm_skel'-- will just ignore that.");
+		INFO_message("*+ You asked to stop inflation at the WM skeleton, but\n"
+                   "\t didn't give a skeleton using `-wm_skel'-- will just"
+                   " ignore that.");
 		SKEL_STOP=0; //reset
 	}
 
 	if( (!HAVESKEL) && TRIM_OFF_WM) {
-		INFO_message("*+ You asked to trim GM input with WM skeleton, but didn't give a skeleton using `-wm_skel'-- will just ignore that.");
+		INFO_message("*+ You asked to trim GM input with WM skeleton, but \n"
+                   "\t didn't give a skeleton using `-wm_skel'-- will just"
+                   " ignore that.");
 		TRIM_OFF_WM = 0; //reset
 	}
 
@@ -464,18 +586,19 @@ int main(int argc, char *argv[]) {
 	}
 
 	// make skeleton: either with file input, or just put 1s everywhere.
-	idx = 0;
+	//idx = 0;
 	// should preserve relative ordering of data
 	for( k=0 ; k<Dim[2] ; k++ ) 
 		for( j=0 ; j<Dim[1] ; j++ ) 
 			for( i=0 ; i<Dim[0] ; i++ ) {
+            idx = THREE_TO_IJK(i,j,k,Dim[0],Dim[0]*Dim[1]);
 				if( ((HAVESKEL==1) && (THD_get_voxel(insetSKEL,idx,0)>SKEL_THR)) 
 					 || (HAVESKEL==0) ) 
 					SKEL[i][j][k] = 1;
 				if( ((HAVE_CSFSKEL==1) && (THD_get_voxel(insetCSF_SKEL,idx,0)>0.5)) 
 					 || (HAVE_CSFSKEL==0) ) 
 					CSF_SKEL[i][j][k] = 1;
-				idx+= 1; 			
+				//idx+= 1; 			
 			}
 
 
@@ -506,18 +629,24 @@ int main(int argc, char *argv[]) {
 	if( (DATA == NULL) || (N_thr == NULL) || (NROI_IN == NULL)
 		 || (temp_arr == NULL) || (VOX == NULL) ) { 
 		fprintf(stderr, "\n\n MemAlloc failure.\n\n");
-		exit(14);
+		exit(14);	
+
 	}
 
 	// STEP 1: go through brik by brik to apply thresholding -> prod bin mask
 	for( m=0 ; m< Dim[3] ; m++ ) {
-		idx = 0;
+      if( HAVE_MASK>1 ) // allow multiple mask briks
+         aaa = m;
+      else
+         aaa = 0;
+		//idx = 0;
 		// should preserve relative ordering of data
 		for( k=0 ; k<Dim[2] ; k++ ) 
 			for( j=0 ; j<Dim[1] ; j++ ) 
 				for( i=0 ; i<Dim[0] ; i++ ) {
+               idx = THREE_TO_IJK(i,j,k,Dim[0],Dim[0]*Dim[1]);
 					if( (HAVE_MASK==0) || 
-						 (HAVE_MASK && ( THD_get_voxel(MASK,idx,0)>0 ) ) )
+						 (HAVE_MASK && ( THD_get_voxel(MASK,idx,aaa)>0 ) ) )
 						if( THD_get_voxel(inset,idx,m) > THR  ) 
 							if( !TRIM_OFF_WM || (TRIM_OFF_WM && !SKEL[i][j][k]) )
 								if( !HAVE_CSFSKEL 
@@ -527,7 +656,7 @@ int main(int argc, char *argv[]) {
 										DATA[i][j][k][m] = BASE_DVAL;
 										N_thr[m]+= 1;
 									}
-					idx+= 1; 					
+					//idx+= 1; 					
 				}
 	}
 	
@@ -544,18 +673,19 @@ int main(int argc, char *argv[]) {
 	for ( j = 0 ; j < max_nroi ; j++ ) 
 		list1[j] = (int *) calloc( 3, sizeof(int) );
 	
-	list1 = calloc( max_nroi, sizeof(int *) );
-	for ( j = 0 ; j < max_nroi ; j++ ) 
-		list1[j] = (int *) calloc( 3, sizeof(int) );
 	// as big as could be needed for labelling...  probably way bigger
 	// than necessary (could buffer/realloc, but just start with this, 
 	// at least for time being)
 	ROI_LABELS_pre = calloc( Dim[3],sizeof(ROI_LABELS_pre));  
 	for(i=0 ; i<Dim[3] ; i++) 
 		ROI_LABELS_pre[i] = calloc(2*N_thr[i],sizeof(int));
+   // always make, for ease of code use later; if no refset given, it
+   // just stays as 0s.  By definition, if HAVEREF>0, then HAVEREF==Dim[3],
+   // so this definition works
+   RESCALES = (int *)calloc(Dim[3], sizeof(int)); 
 
-	if( (list1 == NULL) || (ROI_LABELS_pre == NULL)
-		 ) { 
+	if( (list1 == NULL) || (ROI_LABELS_pre == NULL) 
+		 || (RESCALES == NULL) ) { 
 		fprintf(stderr, "\n\n MemAlloc failure.\n\n");
 		exit(15);
 	}		
@@ -566,6 +696,10 @@ int main(int argc, char *argv[]) {
 	// ****************************************************************
 	// ****************************************************************
 	
+   if(HOT_POINTS)
+      INFO_message("Will shrink large clusters to keep at most %d voxels"
+                   " of high values.", HOT_POINTS);
+
 	// STEP 2: label separate ROIs with ints
 	for( m=0 ; m<Dim[3] ; m++ ) {
 		// make it bigger than any final index possibly could be
@@ -593,13 +727,13 @@ int main(int argc, char *argv[]) {
 								for( jj=-DEP ; jj<=DEP ; jj++)
 									for( kk=-DEP ; kk<=DEP ; kk++)
 										// need to share face or edge, not only vertex
-										if(abs(ii)+abs(jj)+abs(kk)<3)
+										if(abs(ii)+abs(jj)+abs(kk)<NEIGHBOR_LIMIT)
 											// keep in bounds
 											if((0 <= X+ii) && (X+ii < Dim[0]) && 
 												(0 <= Y+jj) && (Y+jj < Dim[1]) && 
 												(0 <= Z+kk) && (Z+kk < Dim[2])) {
 												// if a neighbor has value of -one...
-												if( DATA[X+ii][Y+jj][Z+kk][m] == BASE_DVAL) {
+												if(DATA[X+ii][Y+jj][Z+kk][m]==BASE_DVAL){
 													DATA[X+ii][Y+jj][Z+kk][m] = index1; // change
 													list1[found][0] = X+ii; // keep the coors
 													list1[found][1] = Y+jj;
@@ -620,15 +754,50 @@ int main(int argc, char *argv[]) {
 							NROI_IN[m]-=1; // reset index value
 						}
 						else {
-							ROI_LABELS_pre[m][NROI_IN[m]] = found; // !! hold value of Nvox in the ROI; ROI_LABEL for the ith NROI is i+N_thr[m].... //index1; // Xth ROI gets value Y
+                     // at this point, put in an optional search through all 'current'
+                     // ROIs to threshold based on value
+                     if( HOT_POINTS && (found > HOT_POINTS) ) {
+
+                        count = found;
+                        fl_sort = (float *)calloc(found,sizeof(float)); 
+                        if( fl_sort == NULL) {
+                           fprintf(stderr, "\n\n MemAlloc failure (fl_sort).\n\n");
+                           exit(14);	
+                        }
+                        
+                        for( mm=0 ; mm<found ; mm++ ) {
+                           idx = THREE_TO_IJK(list1[mm][0],list1[mm][1],list1[mm][2],
+                                              Dim[0],Dim[0]*Dim[1]);
+                           fl_sort[mm] = THD_get_voxel(inset,idx,m);
+                        }
+                        qsort(fl_sort, count, sizeof(float), compfunc_desc);
+                        hot_val = fl_sort[HOT_POINTS];
+
+                        for( mm=0 ; mm<count ; mm++ ) {
+                           idx = THREE_TO_IJK(list1[mm][0],list1[mm][1],list1[mm][2],
+                                              Dim[0],Dim[0]*Dim[1]);
+                           if( !(THD_get_voxel(inset,idx,m) > hot_val) ) {
+                              DATA[list1[mm][0]][list1[mm][1]][list1[mm][2]][m] = 0;
+                              found--;
+                           }
+                        }
+                        free(fl_sort);
+                        
+                        found = count;// just reset for resetting list1 next
+                     }
+                     
+                     // !! hold value of Nvox in the ROI; ROI_LABEL
+                     // for the ith NROI is
+                     // i+N_thr[m].... //index1; // Xth ROI gets value Y
+							ROI_LABELS_pre[m][NROI_IN[m]] = found; 
 							VOX[m]+=found;
 						}
-
+      
 						// so, we found a 1, grew it out and changed all assoc.
 						// indices-- keep track of how many voxels there were...
 						// numperroi1(index1) = found;
 						for( ii=0 ; ii<found ; ii++) // clean up list for use again
-							for( j=0 ; jj<3 ; jj++ )
+							for( jj=0 ; jj<3 ; jj++ )
 								list1[ii][jj]=0;
 					}
 				}
@@ -641,14 +810,62 @@ int main(int argc, char *argv[]) {
 		NROI_REF = (int *)calloc(HAVEREF, sizeof(int)); 
 		NROI_REF_b = (int *)calloc(HAVEREF, sizeof(int)); // for counting
 		INVROI_REF = (int *)calloc(HAVEREF, sizeof(int)); 
+      temp_ref = calloc( HAVEREF,sizeof(temp_ref));  // XYZ components
+      for(i=0 ; i<HAVEREF ; i++) 
+         temp_ref[i] = calloc( Nvox,sizeof(short int) ); 
+
 		if( (NROI_REF == NULL) || (NROI_REF == NULL) || (NROI_REF_b == NULL) 
-			 ) {
+			 || (temp_ref == NULL) ) {
 			fprintf(stderr, "\n\n MemAlloc failure.\n\n");
 			exit(122);
 		}
 		
+      // NEW: allow for having `antimask'/negative/NOT-ROIs by simple
+      // rescaling up of REFSET values, if there's a negative present;
+      // then do normal labelling, and then rescale down again.
+		for( i=0 ; i<HAVEREF ; i++) {
+         THD_subbrick_minmax(insetREF, i, 1,&dum1[0], &dum2[0]);
+         if( dum1[0]<0 )//??inset-->fixed
+            RESCALES[i] = 1 - ((int) dum1[0]);
+         //printf("\n%d\t%d --> refscal=%d",(int) dum1[0], 
+         //       (int) dum2[0], RESCALES[i]);
+      }
+
+      // rescale values as necessary
+      for( m=0 ; m<Dim[3] ; m++ ) {
+			//idx=0;
+			for( k=0 ; k<Dim[2] ; k++ ) 
+				for( j=0 ; j<Dim[1] ; j++ ) 
+					for( i=0 ; i<Dim[0] ; i++ ) {
+                  idx = THREE_TO_IJK(i,j,k,Dim[0],Dim[0]*Dim[1]);
+						if( THD_get_voxel(insetREF,idx,m)>0.5 ||
+                      THD_get_voxel(insetREF,idx,m)<-0.5 ) {
+                     temp_ref[m][idx] = (short int) 
+                        THD_get_voxel(insetREF,idx,m);
+                     if( RESCALES[m] )
+                        temp_ref[m][idx]+= RESCALES[m];
+                  }
+                  //idx++;
+               }
+      }
+      set_REFSCAL = EDIT_empty_copy( insetREF ) ; 
+      EDIT_dset_items(set_REFSCAL,
+							 ADN_datum_all , MRI_short , 
+							 ADN_none ) ;
+
+      for( m=0 ; m<Dim[3] ; m++ ) {
+         EDIT_substitute_brick(set_REFSCAL, m, MRI_short, temp_ref[m]);
+         temp_ref[m]=NULL; // to not get into trouble...
+      }
+      free(temp_ref);
+
+      for( i=0 ; i<HAVEREF ; i++) {
+         THD_subbrick_minmax(set_REFSCAL, i, 1,&dum1[0], &dum2[0]);
+         //printf("\nREFSCAL[%d] %d\t%d",i,(int) dum1[0],(int) dum2[0]);
+      }
+      
 		for( i=0 ; i<HAVEREF ; i++) 
-			INVROI_REF[i] = (int) THD_subbrick_max(insetREF, i, 1);//??inset-->fixed
+			INVROI_REF[i] = (int) THD_subbrick_max(set_REFSCAL, i, 1);//??inset-->fixed
 		
 		ROI_LABELS_REF = calloc( HAVEREF,sizeof(ROI_LABELS_REF));  
 		for(i=0 ; i<HAVEREF ; i++) 
@@ -663,7 +880,7 @@ int main(int argc, char *argv[]) {
 		
 		// Step 3A-2: find out the labels in the ref, organize them
 		//            both backwards and forwards.
-		bb = ViveLeRoi(insetREF, 
+		bb = ViveLeRoi(set_REFSCAL,
 							ROI_LABELS_REF, INV_LABELS_REF, 
 							NROI_REF,       INVROI_REF);
 		if( bb != 1)
@@ -704,21 +921,22 @@ int main(int argc, char *argv[]) {
 		// Also, count number of vox per refset ROI
 		for( m=0 ; m<Dim[3] ; m++ ) {
 
-			idx=0;
+			//idx=0;
 			for( k=0 ; k<Dim[2] ; k++ ) 
 				for( j=0 ; j<Dim[1] ; j++ ) 
 					for( i=0 ; i<Dim[0] ; i++ ) {
-						if( THD_get_voxel(insetREF,idx,m)>0 ) {
+                  idx = THREE_TO_IJK(i,j,k,Dim[0],Dim[0]*Dim[1]);
+						if( THD_get_voxel(set_REFSCAL,idx,m)>0 ) {
 							// for ease/shortcut, define X, the compact form of
 							// the refROI label index, and Y, the inset ROI smallval
-							X = INV_LABELS_REF[m][(int) THD_get_voxel(insetREF,idx,m)];
+							X = INV_LABELS_REF[m][(int) THD_get_voxel(set_REFSCAL,idx,m)];
 							N_refvox_R[m][X]+=1;
 							if( DATA[i][j][k][m]>0 ) {
 								Y = DATA[i][j][k][m] - N_thr[m];
 								OLAP_RI[m][X][Y][0]+=1;
 							}
 						}
-						idx++;
+						//idx++;
 					}
 		}
 		
@@ -798,10 +1016,11 @@ int main(int argc, char *argv[]) {
 		for( m=0 ; m<Dim[3] ; m++ ) {
 			
 			relab_vox[m]=0;
-			idx=0;
+			//idx=0;
 			for( k=0 ; k<Dim[2] ; k++ ) 
 				for( j=0 ; j<Dim[1] ; j++ ) 
 					for( i=0 ; i<Dim[0] ; i++ ) {
+                  idx = THREE_TO_IJK(i,j,k,Dim[0],Dim[0]*Dim[1]);
 						if( DATA[i][j][k][m]>0 ) {
 							Y = DATA[i][j][k][m] - N_thr[m];
 							if( OLAP_RI[m][0][Y][1]<0 ) {// was neg val when stored
@@ -814,14 +1033,14 @@ int main(int argc, char *argv[]) {
 									relab_vox[m]++;
 								}
 								else if( (OLAP_RI[m][ii][Y][1]==4) &&
-											(THD_get_voxel(insetREF,idx,m)>0) ) {// relabel
-									DATA[i][j][k][m] = THD_get_voxel(insetREF,idx,m);
+											(THD_get_voxel(set_REFSCAL,idx,m)>0) ) {// relabel
+									DATA[i][j][k][m] = THD_get_voxel(set_REFSCAL,idx,m);
 									relab_vox[m]++;
 									break;
 								}
 							}
 						}
-						idx++;
+						//idx++;
 					}
 		}
 
@@ -849,7 +1068,7 @@ int main(int argc, char *argv[]) {
 									for( jj=-DEP ; jj<=DEP ; jj++)
 										for( kk=-DEP ; kk<=DEP ; kk++)
 											// need to share face or edge, not only vertex
-											if(abs(ii)+abs(jj)+abs(kk)<3)
+											if(abs(ii)+abs(jj)+abs(kk)<NEIGHBOR_LIMIT) //3)
 												
 												// keep in bounds
 												if((0 <= i+ii) && (i+ii < Dim[0]) && 
@@ -927,7 +1146,8 @@ int main(int argc, char *argv[]) {
 		for( k=0 ; k<Dim[2] ; k++ ) 
 			for( j=0 ; j<Dim[1] ; j++ ) 
 				for( i=0 ; i<Dim[0] ; i++ ) {
-					temp_arr[m][idx] = DATA[i][j][k][m];
+               if( DATA[i][j][k][m] )// account for neg values rescaled
+                  temp_arr[m][idx] = DATA[i][j][k][m]-RESCALES[m];
 					idx+=1;
 				}
 		EDIT_substitute_brick(outsetGM, m, MRI_short, temp_arr[m]); 
@@ -1022,16 +1242,20 @@ int main(int argc, char *argv[]) {
 									for( jj=-DEP ; jj<=DEP ; jj++)
 										for( kk=-DEP ; kk<=DEP ; kk++)
 											// need to share face or edge, not only vertex
-											if(abs(ii)+abs(jj)+abs(kk)<3)
+											if(abs(ii)+abs(jj)+abs(kk)<NEIGHBOR_LIMIT) //3)
 												
 												// keep in bounds
 												if((0 <= i+ii) && (i+ii < Dim[0]) && 
 													(0 <= j+jj) && (j+jj < Dim[1]) && 
 													(0 <= k+kk) && (k+kk < Dim[2])) {
 													idx = THREE_TO_IJK(i+ii,j+jj,k+kk,Dim[0],Dim[0]*Dim[1]);
+                                       if( HAVE_MASK>1 )
+                                          aaa = m;
+                                       else
+                                          aaa = 0;
 													if( (HAVE_MASK==0) || 
 														 (HAVE_MASK && 
-														  ( THD_get_voxel(MASK,idx,0)>0 ) ) ) {
+														  ( THD_get_voxel(MASK,idx,aaa)>0 ) ) ) {
 														
 														// grow if ngb=0; give temp value
 														// of -[value it will have]
@@ -1091,7 +1315,8 @@ int main(int argc, char *argv[]) {
 		for( k=0 ; k<Dim[2] ; k++ ) 
 			for( j=0 ; j<Dim[1] ; j++ ) 
 				for( i=0 ; i<Dim[0] ; i++ ) {
-					temp_arr2[m][idx] = DATA[i][j][k][m];
+               if( DATA[i][j][k][m] )
+                  temp_arr2[m][idx] = DATA[i][j][k][m]-RESCALES[m];
 					idx+=1;
 				}
 		EDIT_substitute_brick(outsetGMI, m, MRI_short, temp_arr2[m]); 
@@ -1172,8 +1397,12 @@ int main(int argc, char *argv[]) {
 		free(NROI_REF_b);
 		free(INVROI_REF);
 		free(EXTRA_LAB);
+      
+      free(set_REFSCAL);
+      DSET_delete(set_REFSCAL);
 	}
-	
+	free(RESCALES);
+
 	for( i=0 ; i<Dim[3] ; i++) {
 		for ( j = 0 ; j<NROI_GM[i]+1 ; j++ ) 
 			free(COUNT_GM[i][j]);
