@@ -1,6 +1,14 @@
 #ifndef TRACKIO_INCLUDED
 #define TRACKIO_INCLUDED
 
+// temporary candidate for NIML string reading based on ZSS's
+// int/float-reading definitions in */suma_afni_surface.h
+#define NI_SETA_STR_tmp(ngr, name, val)  {\
+   char m_stmp[200]; sprintf(m_stmp,"%s", (val));   \
+   NI_set_attribute(ngr, name, m_stmp);  \
+}
+
+
 typedef struct {
    int id;     /* some identifier */
    int N_pts3;  /* total number of values in pts */
@@ -15,6 +23,9 @@ typedef struct {
    int N_tracts;
    int N_allocated;
    TAYLOR_TRACT *tracts;
+   int *tract_P0_offset_private; /* Index of 1st point in each tract 
+                                    Index of 1st point of 1st tract is 0 */
+   int N_points_private; /* Sum of points in all tracts of bundle */
 } TAYLOR_BUNDLE;
 
 typedef struct {
@@ -26,11 +37,39 @@ typedef struct {
    TAYLOR_BUNDLE **tbv;
    int *bundle_tags;
    int *bundle_alt_tags;
+   int N_points_private; /* Num of points in all tracts of all bundles in net */
+   int N_tracts_private; /* Sum of number of tracts in all bundles */
+   int Longest_tract_length_private; /* Length in points of longest tract */
+   int Longest_tract_index_in_bundle_private; /* longest tract index in bundle */
+   int Longest_tract_bundle_index_in_network_private; /* longest tract bundle */ 
 } TAYLOR_NETWORK;
 
+typedef struct {
+   THD_3dim_dataset *grid;
+} INSTA_TRACT_SETUP;
+
+int Free_Insta_Tract_Setup(INSTA_TRACT_SETUP *ITS);
+INSTA_TRACT_SETUP *New_Insta_Tract_Setup(INSTA_TRACT_SETUP *ITS);
+
+float Tract_Length(TAYLOR_TRACT *tt);
 void Show_Taylor_Network(TAYLOR_NETWORK *network, FILE *out, int mx, int mxb);
 void Show_Taylor_Bundle(TAYLOR_BUNDLE *bundle, FILE *out, int mx);
 void Show_Taylor_Tract(TAYLOR_TRACT *tract, FILE *out, int mx);
+TAYLOR_TRACT *Create_Tract_NEW(int ptA, int ptB, float **pts_buff, 
+                               int id, THD_3dim_dataset *grid);
+int Bundle_N_points(TAYLOR_BUNDLE *bun, byte recalc);
+int Network_N_points(TAYLOR_NETWORK *network, byte recalc);
+int Network_N_tracts(TAYLOR_NETWORK *network, byte recalc);
+int Network_N_bundles(TAYLOR_NETWORK *network);
+int Network_Max_tract_length(TAYLOR_NETWORK *net, byte recalc,
+                             int *t, int *b);
+int Network_PTB_to_1P(TAYLOR_NETWORK *network, int p, int t, int b);
+int Network_TB_to_1T(TAYLOR_NETWORK *net, int t, int b);
+int Network_1P_to_PTB(TAYLOR_NETWORK *network, int P1, 
+                      int *p, int *t, int *b, int *l);
+int Network_1T_to_TB(TAYLOR_NETWORK *net, int TT, int *t, int *b, 
+                     int *P0, int *P1);
+int Network_1B_to_1P(TAYLOR_NETWORK *net, int BB, int *PP1);
 TAYLOR_TRACT *Create_Tract(int N_ptsB, float **pts_buffB,
                           int N_ptsF, float **pts_buffF, 
                           int id, THD_3dim_dataset *grid);
@@ -47,6 +86,7 @@ TAYLOR_NETWORK *AppAddBundleToNetwork(TAYLOR_NETWORK *network,
                                       TAYLOR_BUNDLE **tb,int tag, int alt_tag,
                                       THD_3dim_dataset *grid);
 NI_group *Network_2_NIgr(TAYLOR_NETWORK *network, int mode);
+NI_group *Network_link(char *filename);
 TAYLOR_NETWORK *NIgr_2_Network(NI_group *ngr); 
 int Write_NI_Network(NI_group *ngr, char *name, char *mode); 
 int Write_Network(TAYLOR_NETWORK *network, char *name, char *mode);
@@ -57,24 +97,25 @@ NI_group * Read_NI_Network(char *name);
 int get_tract_verb(void);
 void set_tract_verb(int v);
 int get_NI_tract_type(void);
-int NI_getTractAlgOpts(NI_element *nel, float *MinFA, float *MaxAngDeg, 
-                       float *MinL, int *SeedPerV, int *M, int *bval);
-NI_element * NI_setTractAlgOpts(NI_element *nel, float *MinFA, 
-										  float *MaxAngDeg, float *MinL, 
-										  int *SeedPerV, int *M, int *bval);
-NI_element *ReadTractAlgOpts(char *fname);
-int NI_getProbTractAlgOpts(NI_element *nel, float *MinFA, float *MaxAngDeg, 
-									float *MinL, float *NmNsFr, int *Nseed, 
-									int *Nmonte, int *M, int *bval);
-NI_element * NI_setProbTractAlgOpts(NI_element *nel, float *MinFA, 
-												float *MaxAngDeg, float *MinL,
-												float *NmNsFr, int *Nseed, 
-												int *Nmonte, int *M, int *bval);
-NI_element *ReadProbTractAlgOpts(char *fname);
+
 // this currently works for both 3dTrack and 3dProbTrack!
 int WriteTractAlgOpts(char *fname, NI_element *nel); 
 
-
+// new versions for MULTI/HARDI: no M and bvals
+int NI_getTractAlgOpts_M(NI_element *nel, float *MinFA, float *MaxAngDeg, 
+                       float *MinL, int *SeedPerV);
+NI_element * NI_setTractAlgOpts_M(NI_element *nel, float *MinFA, 
+										  float *MaxAngDeg, float *MinL, 
+										  int *SeedPerV);
+NI_element *ReadTractAlgOpts_M(char *fname);
+int NI_getProbTractAlgOpts_M(NI_element *nel, float *MinFA, float *MaxAngDeg, 
+									float *MinL, float *NmNsFr, int *Nseed, 
+									int *Nmonte);
+NI_element * NI_setProbTractAlgOpts_M(NI_element *nel, float *MinFA, 
+												float *MaxAngDeg, float *MinL,
+												float *NmNsFr, int *Nseed, 
+												int *Nmonte);
+NI_element *ReadProbTractAlgOpts_M(char *fname);
 
 // TrackVis requirements for *.trk file, defining the header as a struct
 typedef struct 
@@ -127,9 +168,19 @@ typedef struct
 } tv_io_header;   
 
 // for writing trackvis track info currently
-int SimpleWriteDetNetTr(FILE *file, int ***idx, THD_3dim_dataset *FA,
-                        THD_3dim_dataset *MD, THD_3dim_dataset *L1,
-                        float **loc, int **locI, int len,
-                        int *TV, int *Dim, float *Ledge);
+int SimpleWriteDetNetTr_M(int N_HAR, FILE *file, int ***idx, 
+                           THD_3dim_dataset **PARS,
+                           int PAR_BOT, int PAR_TOP,
+                           float **loc, int **locI, int len,
+                           int *TV, int *Dim, float *Ledge);
+
+
+NI_element * ReadDTI_inputs(char *fname);
+int NI_getDTI_inputs( NI_element *nel, 
+                      char **NameVEC, //[3],
+                      char *NameXF, 
+                      char **NameSCAL, //[3], 
+                      char **NameP, //[4],
+                      int *extrafile, int *pars_top);
 
 #endif
