@@ -18,8 +18,7 @@ g_help_string = """
     Basic Usage:
       auto_warp.py -base TT_N27+tlrc -input anat.nii  \\
                    -skull_strip_input yes
-      
-        
+
     ---------------------------------------------
     REQUIRED OPTIONS:
     
@@ -27,8 +26,14 @@ g_help_string = """
     -input  : name of dataset to be registered
     
     MAJOR OPTIONS:
+
     -help       : this help message
-    
+
+    OTHER OPTIONS:
+
+    -qblur bB bS : specify 3dQwarp blurs for base and source volumes
+    -qworkhard i0 i1: set the two values for 3dQwarp's -workhard option
+    -qw_opts 'OPTS': Pass all of OPTS as extra options directly to 3dQwarp 
 """   
 
 ## BEGIN common functions across scripts (loosely of course)
@@ -50,6 +55,9 @@ class RegWrap:
       self.deoblique_flag = 1  # deoblique datasets first
       self.deoblique_opt = "" # deobliquing/obliquing options
       self.at_opt = "" # @auto_tlrc options
+      self.qw_opts = "" # 3dQwarp extra options
+      self.qworkhard = [0, 1]
+      self.qblur = [-3, -3]# blurs for 3dQwarp
       self.output_dir = '' # user assigned path for anat and EPI
       
       return
@@ -119,17 +127,29 @@ class RegWrap:
 
 
       #resolutions for computing transforms
+
+      # 16 Dec 2013 [rickr]
+      self.valid_opts.add_opt('-qblur', 2, [],
+             helpstr="3dQwarp base and source blurs (FWHM)\n")
+
+      # June 2nd 2014 [ZSS]
+      self.valid_opts.add_opt('-qw_opts', -1, [],
+             helpstr="3dQwarp miscellaneous options.\n"  \
+                     "Parameters will get passed directly to 3dQwarp.\n")
+      self.valid_opts.add_opt('-qworkhard', 2, [0, 1],
+             helpstr="3dQwarp -workhard values\n")
+             
       self.valid_opts.add_opt('-warp_dxyz', 1,[0.0],\
              helpstr="Resolution used for computing warp (cubic only)\n")
       self.valid_opts.add_opt('-affine_dxyz', 1,[0.0],\
              helpstr="Resolution used for computing initial transform (cubic only)\n")
       self.valid_opts.add_opt('-affine_input_xmat', 1,deflist=['AUTO'],\
              helpstr="Affine transform to put input in standard space.\n"\
-                     "Special values are 'AUTO' to use @auto_tlrc\n"\
-                     "                   'ID' to do nothing\n"\
-                     "                   'FILE.1D' for a pre-computed matrix\n"\
-                     "                             FILE.1D will get applied to\n"\
-                     "                             the input before Qwarping\n")
+                     "Special values are:\n"\
+                     "    'AUTO' to use @auto_tlrc\n"\
+                     "    'ID' to do nothing\n"\
+                     "    'FILE.1D' for a pre-computed matrix FILE.1D will\n"\
+                     "              get applied to the input before Qwarping\n")
       self.valid_opts.add_opt('-smooth_anat', -1,[],\
              helpstr="Smooth anatomy before registration\n")
       self.valid_opts.add_opt('-smooth_base', -1,[],\
@@ -140,9 +160,9 @@ class RegWrap:
              helpstr="Set directory for output datasets\n")
       
       self.valid_opts.add_opt('-followers', npar=-1, deflist=[],\
-             helpstr="Spercify follower datasets\n")
+             helpstr="Specify follower datasets\n")
       self.valid_opts.add_opt('-affine_followers_xmat', npar=-1, deflist=[],\
-             helpstr="Spercify follower datasets' affine transforms\n")    
+             helpstr="Specify follower datasets' affine transforms\n")    
       self.valid_opts.trailers = 0   # do not allow unknown options
         
   
@@ -194,6 +214,26 @@ class RegWrap:
           if((opt=="") or (opt==" ")) :
             self.error_msg("Cannot have blank suffix")
             ps.ciao(1);
+
+      # 13 Dec, 2013 [rickr] - for Peter Molfese
+      vals, rv = opt_list.get_type_list(float, '-qblur', length=2)
+      if rv: ps.ciao(1)
+      if vals != None: self.qblur = vals
+      
+      
+      vals, rv = opt_list.get_type_list(float, '-qworkhard', length=2)
+      if rv: ps.ciao(1)
+      if vals != None: 
+         if len(vals) == 2:
+            self.qworkhard = vals
+         else:
+            ps.ciao(1)
+         
+      opt = opt_list.find_opt('-qw_opts')
+      istr = '  '
+      if opt != None:
+         self.qw_opts = '    %s' % \
+          ' '.join(UTIL.quotize_list(opt.parlist, '\\\n%s    '%istr, 1))
       
       opt = opt_list.find_opt('-warp_dxyz')    
       if opt != None: 
@@ -325,8 +365,11 @@ class RegWrap:
                print "   %-20s   %s" % \
                   ("   allowed:" , string.join(opt.acceptlist,', '))
             if (opt.deflist):
-               print "   %-20s   %s" % \
-                  ("   default:",string.join(opt.deflist,' '))
+               if type(opt.deflist[0]) != str:  # 31 Mar 2014 [rickr]
+                  print "   %-20s   %s" % ("   default:",opt.deflist)
+               else:
+                  print "   %-20s   %s" % \
+                     ("   default:",string.join(opt.deflist,' '))
       return 1
    
    # remove all the temporary files for epi and anat base names
@@ -632,7 +675,7 @@ class RegWrap:
             self.error_msg("Failed in affine step");
             ps.ciao(1)
          xmat = "%s.Xat.1D" % n.prefix
-         if (not os.path.isfile(xmat)):
+         if (not os.path.isfile(xmat) and not ps.dry_run()):
             self.error_msg("Failed to find xmat %s" % xmat);
             ps.ciao(1)
       else:
@@ -650,13 +693,17 @@ class RegWrap:
       n = a.new(new_pref=prefix, parse_pref=1)
       if (not n.exist() or ps.rewrite or ps.dry_run()):
          n.delete(ps.oexec)
+         if self.qworkhard[0] < 0:
+            whopt = '-workhard'
+         else: whopt = "-workhard:%d:%d" % (self.qworkhard[0], self.qworkhard[1])
          com = shell_com(  \
                 "3dQwarp                                       "\
                 "         -prefix %s                           "\
-                "         -blur 0 3                            "\
-                "         -useweight %s %s                     "\
-                % ( n.input(), b.input(), a.input()), \
-                ps.oexec)
+                "         -blur %s %s %s             "\
+                "         -useweight %s %s  %s                 "\
+                % ( n.input(), self.qblur[0], self.qblur[1],
+                    whopt,
+                    b.input(), a.input(), self.qw_opts), ps.oexec)
          com.run()
          if (not n.exist() and not ps.dry_run()):
             self.error_msg("Failed in warping step");
@@ -668,7 +715,7 @@ class RegWrap:
       
       return (n,w)
       
-   def qwarp_applying(self, a, aff, wrp, prefix=None, dxyz=0.0):
+   def qwarp_applying(self, a, aff, wrp, prefix=None, dxyz=0.0, master=None):
       self.info_msg( "Applying warps to %s" % \
            ( a.input() ))
       if (prefix==None):
@@ -685,15 +732,20 @@ class RegWrap:
             dxopt = ""
          else:
             dxopt = "-dxyz %f" % dxyz
+
+         # warp datasets may need to grow, so allow for a different master
+         if master == None: mast_str = "NWARP"
+         else:              mast_str = "%s" % master.input()
+
          com = shell_com(  \
                 "3dNwarpApply          "\
                 "-nwarp %s             "\
-                "-master NWARP         "\
+                "-master %s            "\
                 "     %s   %s          "\
                 "-source %s            "\
                 "-prefix %s            "\
-                % ( wrp.input(), waff, dxopt, a.input(), n.input()), \
-                ps.oexec)
+                % ( wrp.input(), mast_str, waff, dxopt, a.input(), n.input()),
+                    ps.oexec)
          com.run()
          if (not n.exist() and not ps.dry_run()):
             n.show()
@@ -766,7 +818,9 @@ if __name__ == '__main__':
    a, ps.warp_input_xform = ps.qwarping(a=a, b=b)
    
    #apply warps
-   aw = ps.qwarp_applying(a=ps.input, aff=ps.affine_input_xmat, wrp=ps.warp_input_xform)
+   # warp datasets may grow, so pass base as master     26 Mar 2014 [rcr/zss]
+   aw = ps.qwarp_applying(a=ps.input, aff=ps.affine_input_xmat,
+                          wrp=ps.warp_input_xform, master=b)
    
    ps.save_history(aw, ps.oexec)
    
