@@ -856,8 +856,10 @@ SMat svdTransposeS(SMat S) {
 void svdWriteDenseArray(double *a, int n, char *filename, char binary) {
   int i;
   FILE *file = svd_writeFile(filename, FALSE);
-  if (!file)
-    return svd_error("svdWriteDenseArray: failed to write %s", filename);
+  if (!file){
+    svd_error("svdWriteDenseArray: failed to write %s", filename);
+    return ;
+  }
   if (binary) {
     svd_writeBinInt(file, n);
     for (i = 0; i < n; i++)
@@ -2132,7 +2134,7 @@ long lanczos_step(SMat A, long first, long last, double *wptr[],
    double t, *mid, rnm = *rnmp, tol = *tolp, anorm;
    long i, j;
 
-    if( SVDVerbosity > 1 ) fprintf(stderr,"[%d.%d]",first,last) ;
+    if( SVDVerbosity > 1 ) fprintf(stderr,"[%d.%d]",(int)first,(int)last) ;
    for (j=first; j<last; j++) {
       mid     = wptr[2];
       wptr[2] = wptr[1];
