@@ -695,7 +695,7 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
 
             if( id < DBLK_BRICK_BYTES(blk,ibr) ){
               fprintf(stderr,
-                      "\n*** Volume file %s only gave %d out of %d bytes needed!\n",
+                      "\n*** Volume file %s only gave %lld out of %lld bytes needed!\n",
                      fnam[ibr] , id , DBLK_BRICK_BYTES(blk,ibr) ) ;
               THD_purge_datablock( blk , blk->malloc_type ) ;
               for( ii=0 ; ii < nv ; ii++ ) free(fnam[ii]) ;
@@ -735,7 +735,7 @@ fprintf(stderr,"VOL[%d]: id=%d\n",ibr,id) ;
 
             if( id < DBLK_BRICK_BYTES(blk,jbr) ){
               fprintf(stderr,
-                      "\n*** Volume file %s only gave %d out of %d bytes needed!\n",
+                      "\n*** Volume file %s only gave %lld out of %lld bytes needed!\n",
                      fnam[ibr] , id , DBLK_BRICK_BYTES(blk,jbr) ) ;
               THD_purge_datablock( blk , blk->malloc_type ) ;
               for( ii=0 ; ii < nv ; ii++ ) free(fnam[ii]) ;
