@@ -42,7 +42,6 @@ mat44 THD_mat44_mul( mat44 A , mat44 B )
 int THD_daxes_to_mat44( THD_dataxes *dax )
 {
    mat44 ijk_to_dxyz , dxyz_to_dicom ;
-   float aaa ;
 
    if( dax == NULL ) return -1 ;
 
@@ -53,14 +52,9 @@ int THD_daxes_to_mat44( THD_dataxes *dax )
                0.0f       , dax->yydel , 0.0f       , dax->yyorg ,
                0.0f       , 0.0f       , dax->zzdel , dax->zzorg  ) ;
 
-   /* set to_dicomm if not valid */
+   /* set to_dicomm (takes dataset order xyz to DICOM order xyz) */
 
-   aaa = fabsf(dax->to_dicomm.mat[0][0])+fabsf(dax->to_dicomm.mat[0][1])
-        +fabsf(dax->to_dicomm.mat[0][2])+fabsf(dax->to_dicomm.mat[1][0])
-        +fabsf(dax->to_dicomm.mat[1][1])+fabsf(dax->to_dicomm.mat[1][2])
-        +fabsf(dax->to_dicomm.mat[2][0])+fabsf(dax->to_dicomm.mat[2][1])
-        +fabsf(dax->to_dicomm.mat[2][2]) ;
-   if( aaa == 0.0f ) THD_set_daxes_to_dicomm(dax) ;
+   THD_set_daxes_to_dicomm(dax) ;
 
    /* dxyz_to_dicom: transforms dataset (x,y,z) coords to DICOM coords */
 
