@@ -80,10 +80,10 @@ double THD_diff_vol_vals(THD_3dim_dataset *d1, THD_3dim_dataset *d2, int scl) {
    
    if (!d1 && !d2) RETURN(dd);
    if (!d1 || !d2) RETURN(-1.0);
-   
+
    if (!EQUIV_GRIDS(d1,d2)) RETURN(-1.0);
-   if (!DSET_NVALS(d1) != !DSET_NVALS(d2)) RETURN(-1.0);
-   
+   if (DSET_NVALS(d1) != DSET_NVALS(d2)) RETURN(-1.0);
+  
    DSET_mallocize(d1) ; DSET_load(d1) ;
    DSET_mallocize(d2) ; DSET_load(d2) ;
    dd = 0.0; denom = 0;
